@@ -1,15 +1,15 @@
 import sys
 
 if sys.version_info < (3, 7):
-    raise ImportError('Your Python version {0} is not supported, please install '
-                      'Python 3.7+'.format('.'.join(map(str, sys.version_info[:3]))))
+    raise RuntimeError('Your Python version {0} is not supported, please install '
+                       'Python 3.7+'.format('.'.join(map(str, sys.version_info[:3]))))
 
-from .abcp import BaseAbcp
-from .cp import AdminApi, ClientApi
+from .base import BaseAbcp
+from .abcp import Abcp
 from .api import check_result, make_request, Methods
 from .exceptions import (NetworkError, UnsupportedHost, UnsupportedLogin, PasswordType, NotEnoughRights, AbcpAPIError,
                          AbcpParameterRequired, TeaPot)
 
 __author__ = 'bl4ckm45k'
-__version__ = '0.5.2'
+__version__ = '1.0.5'
 __email__ = 'nonpowa@gmail.com'
